.. _changes:

Changes
=======

0.10.2 - 2025-02-23
-------------------

- Support more YUV subsampling and planar formats


0.10.1 - 2025-01-17
-------------------

- Advertise Python 3.13 compatibility
- Switch to uv


0.10.0 - 2024-05-25
-------------------

- Increase minimum required Python version to 3.10
- Improve type hints


0.9.2 - 2024-02-29
------------------

- Update for rosbags 0.9.20
- Do not inplace byteswap readonly arrays. `#1`_

.. _#1: https://gitlab.com/ternaris/rosbags-image/issues/1


0.9.1 - 2022-09-08
------------------

- Depend on headless version of cv2


0.9.0 - 2022-04-11
------------------

- Initial Release
